"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Apibara Stream service."""
import abc
import collections.abc
import grpc
import apibara.protocol.proto.stream_pb2 as stream_pb2

class StreamStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    StreamData: grpc.StreamStreamMultiCallable[
        stream_pb2.StreamDataRequest,
        stream_pb2.StreamDataResponse,
    ]
    """Stream data from the node."""

class StreamServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def StreamData(
        self,
        request_iterator: collections.abc.Iterator[stream_pb2.StreamDataRequest],
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[stream_pb2.StreamDataResponse]:
        """Stream data from the node."""

def add_StreamServicer_to_server(
    servicer: StreamServicer, server: grpc.Server
) -> None: ...
